<?php

if ( ! function_exists( 'esmi_theme_setup' ) ):
function esmi_theme_setup() {
	
	// Load language files
	load_theme_textdomain( 'zenlite', TEMPLATEPATH . '/langs' );
	$locale = get_locale();
	$locale_file = TEMPLATEPATH . "/langs/$locale.php";
	if ( is_readable( $locale_file ) ) require_once( $locale_file );
	
	// Add post thumbnail & feed link support
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'automatic-feed-links' );

	// Get the post thumbnail dimensions from Settings/Media
	define('THUMB_WIDTH', get_option('thumbnail_size_w'));
	define('THUMB_HEIGHT', get_option('thumbnail_size_h'));
	set_post_thumbnail_size( THUMB_WIDTH, THUMB_HEIGHT ); // box (proportional) resize mode
	
	// Set up a proper &hellip;for post extracts
	function theme_proper_hellip($more) {
		return '&hellip;';
	}
	add_filter('excerpt_more', 'theme_proper_hellip');
	
	// remove gallery css
	function theme_remove_gallery_css( $css ) {
		return preg_replace( "#<style type='text/css'>(.*?)</style>#s", '', $css );
	}
	add_filter( 'gallery_style', 'theme_remove_gallery_css' );
	
	// Correct image path issue in thickbox
	function theme_load_tb_fix() {
		echo "\n" . '<script type="text/javascript">tb_pathToImage = "' . site_url() . '/wp-includes/js/thickbox/loadingAnimation.gif";tb_closeImage = "' . site_url() . '/wp-includes/js/thickbox/tb-close.png";</script>'. "\n";
	}
	add_action('wp_footer', 'theme_load_tb_fix');
	
	// Add support for custom background
	if( function_exists ('add_custom_background') ) add_custom_background();
	
	// Header & Background customisation/
	define('HEADER_IMAGE_WIDTH', apply_filters( 'zenlite_header_image_width',1000 ) );
	define('HEADER_IMAGE_HEIGHT', apply_filters( 'zenlite_header_image_height', 150 ) );
	define('HEADER_IMAGE', get_bloginfo('stylesheet_directory') . '/images/banner.jpg');
	define('HEADER_TEXTCOLOR', '606060');
	define ('BACKGROUND_COLOR', 'fff');
	define ('BACKGROUND_IMAGE', '');

}
endif;
add_action( 'after_setup_theme', 'esmi_theme_setup' );

// Register sidebar(s)
if ( !function_exists( 'theme_widgets_init' )) :
function theme_widgets_init() {
	register_sidebar(array(
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h2 class="widgettitle">',
		'after_title' => '</h2>',
	));
}
endif;
add_action( 'widgets_init', 'theme_widgets_init' );

// add custom menu support
if ( function_exists( 'register_nav_menu' ) && !function_exists( 'register_theme_menus' )) :
function register_theme_menus() {
	register_nav_menu( 'primary', __( 'Primary', 'zenlite' ) );
}
endif;
add_action( 'init', 'register_theme_menus' );

// Add thickbox to public-facing image attachment pages only
if ( !function_exists( 'theme_thickbox_init' ) ) :
function theme_thickbox_init() {
	if (is_attachment() && substr(get_post_mime_type(), 0,5) == 'image') {
		add_thickbox();
	}
}
endif;
add_action('template_redirect', 'theme_thickbox_init');

// Set image max width in content area
if ( !function_exists( 'theme_content_width' ) ) :
function theme_content_width() {
	$GLOBALS['content_width'] = 900;
}
endif;

// output header image & text CSS
if ( !function_exists( 'theme_custom_header_style' ) ) :
	function theme_custom_header_style() {
		echo '<style type="text/css" media="screen">'."\n";
		if( get_header_image() != '' ) echo '#header-image {background-image:url(' . get_header_image() . ');}';
		if( get_header_textcolor() == 'blank' ) echo '#header h1,#header h1 a {position:absolute;top:-5000px;left:-5000px;}';
		else echo '#header h1,#header h1 a {color:#' . get_header_textcolor() . ';}';
		echo "\n</style>\n\n";
	}
endif;

// Style header customisation in the Admin area
if ( !function_exists( 'theme_admin_header_style' ) ) :
function theme_admin_header_style() {
?>
<style type="text/css">
#headimg {
	height:150px;
	padding:0;
	margin:70px 0 0;
	background-image:url(images/banner.jpg);
	background-repeat:no-repeat;
	background-position:top left;
	border-top:3px double #aaa;
	border-bottom:3px double #aaa;
}
#headimg h1,#headimg #desc {
	text-align:center;
	font-weight:normal;
	letter-spacing:.02em;
	position:relative;
	top:-70px;
}
#headimg h1 {
	margin:0;
	padding:0 15px;
	font-size:30px;
	line-height:1.2em;
	color:#606060;
}
#headimg #desc {
	display:block;
	margin:0;
	padding:0 0 13px;
	font-size:20px;
	color:#707070;
}
#headimg a {
	text-decoration:none;
}
#headimg a:hover {
	text-decoration:underline;
}
</style>
<?php
}
endif;
add_custom_image_header('', 'theme_admin_header_style');

// Amend comment form fields
if ( !function_exists( 'theme_comment_fields' ) ) :
	function theme_comment_fields($fields) {
		$commenter = wp_get_current_commenter();
		$req = get_option('require_name_email');
		if( $req ) $reqd = '<span class="required">' . __('*', 'zenlite') . '</span>';

		$fields['author'] = '<p class="comment-form-author"><label class="text" for="author">' . __( 'Name', 'zenlite' ) . $reqd . '</label><input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" /></p>';

		$fields['email'] = '<p class="comment-form-email"><label class="text" for="email">' . __( 'Email', 'zenlite' ) . $reqd . '</label><input id="email" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30" />' . '</p>';

		$fields['url']   = '<p class="comment-form-url"><label class="text" for="url">' . __( 'Website', 'zenlite') . '</label>' . '<input id="url" name="url" type="text" value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="30" /></p>';

		return $fields;
	}
endif;
add_filter('comment_form_default_fields','theme_comment_fields');

// Amend comment form arguments
if ( ! function_exists( 'theme_comment_form_args' ) ) :
	function theme_comment_form_args($user_identity, $post_id, $req) {
		$args = array(
			'comment_notes_before' => '<p class="comment-notes"><label for="author">' . ( $req ? __( ' Required fields are marked ', 'zenlite') . '<span class="required">' . __('*', 'zenlite') . '</span><br />' : '' ) . __( 'Your email address will <em>never</em> be published or shared.' ) . '</label></p>',

			'logged_in_as' => '<p class="logged-in-as"><label for="comment">' . sprintf( __( 'Logged in as <a href="%s">%s</a>. <a href="%s" title="Log out of this account">Log out?</a></label></p>' ), admin_url( 'profile.php' ), $user_identity, wp_logout_url( apply_filters( 'the_permalink', get_permalink( $post_id ) ) ) ),
			
			'comment_notes_after' => '<p class="form-allowed-tags"><label for="comment">' . __( 'You may use these <abbr title="eXtensible HyperText Markup Language">XHTML</abbr> tags and attributes:', 'zenlite' ) . ' <code>' .  allowed_tags() . '</code></label></p>',
			
			'comment_field' => '<p class="comment-form-comment"><label for="comment">' . _x( 'Comment', 'noun' ) . '</label><textarea id="comment" name="comment" cols="45" rows="8"></textarea></p>',
			'label_submit'=>'Submit Reply'
		);
		return $args;
	}
endif;

// Called in sidebar.php for categories if no custom menu is defined
if ( !function_exists( 'theme_callback_cats' ) ) :
	function theme_callback_cats() {
		wp_list_categories('title_li=');
	}
endif;

// Called in sidebar.php for Pages  if no custom menu is defined
if ( !function_exists( 'theme_callback_pages' ) ) :
	function theme_callback_pages() {
		wp_list_pages('title_li=');
	}
endif;


// ZENLITE THEME OPTIONS

// set defaults
$zenlite_default_options=array();
$zenlite_options = get_option('zenlite_theme_options'); 
set_options();

// Update theme options
function set_options() {
	global $zenlite_options;
	$zenlite_default_options['menu_type']=0;
	$zenlite_default_options['author_link']=0;
	
	$existing_options = get_option('zenlite_theme_options'); 
	if (is_array($existing_options)) {
		foreach ($existing_options as $key=>$val) { 
			$zenlite_options[$key]=$val;
		}
		foreach ($zenlite_default_options as $key=>$val) { 
			if (!$zenlite_options[$key]) $zenlite_options[$key]=$val;
		}
	}
	else {
		$zenlite_options=$zenlite_default_options;
		update_option('zenlite_theme_options', $zenlite_options);
	}
}

// Theme options form
function zenlite_theme_admin() {
	?>
	<div class="wrap">
	<?php
	echo '<h2>'.__('Theme Options','zenlite_theme').'</h2>'."\n";
	global $wpdb;
	$zenlite_updated_options = array();
	if( $_POST  && check_admin_referer($action ='update_options', $query_arg = 'theme_options_form') ) {
		if(isset($_POST['zenlite_reset']) ) {
			delete_option('zenlite_theme_options');
			echo'<div id="message" class="updated fade"><p>'.__('All current theme options have been deleted.','zenlite_theme').'</p></div>'."\n";
		}
		else {
			update_option('zenlite_theme_options',$zenlite_updated_options);
			echo'<div id="message" class="updated fade"><p>'.__('The current theme has been updated.','zenlite_theme').'</p></div>'."\n";
		}
	}
	$zenlite_options = get_option('zenlite_theme_options');
	?>
	<form method="post" action="" id="zenlite_options"><div>
	<?php wp_nonce_field( $action = 'update_options', $name = 'theme_options_form', $referer = true , $echo = true) ;?>
	
	<fieldset>
	<legend><?php _e('Use the navigation menu to display links to:','zenlite_theme'); ?></legend>
	<p><input type="radio" id="zenlite_pages_yes" name="menu_type" value="0" <?php if (!isset($zenlite_options['menu_type']) || $zenlite_options['menu_type'] == 0) echo ' checked="checked"';?> /> <label for="zenlite_pages_yes"><?php _e('Pages','zenlite_theme'); ?></label><br />
	
	<input type="radio" id="zenlite_pages_no" name="menu_type" value="1" 
	<?php if (isset($zenlite_options['menu_type']) && $zenlite_options['menu_type'] == 1) echo ' checked="checked"';?> /> <label for="zenlite_pages_no"><?php _e('Categories','zenlite_theme'); ?></label></p>
	</fieldset>
	
	<fieldset>
	<legend><?php _e('Display an author link on posts?','zenlite_theme'); ?></legend>
	<p><input type="radio" id="zenlite_author_link_yes" name="author_link" value="0" <?php if (!isset($zenlite_options['author_link']) || $zenlite_options['author_link'] == 0) echo ' checked="checked"';?> /> <label for="zenlite_author_link_yes"><?php _e('Yes','zenlite_theme'); ?></label><br />

	<input type="radio" id="zenlite_author_link_no" name="author_link" value="1" <?php if (isset($zenlite_options['author_link']) && $zenlite_options['author_link'] == 1) echo ' checked="checked"';?> /> <label for="zenlite_author_link_no"><?php _e('No','zenlite_theme'); ?></label></p>
	</fieldset>
	
	<div>
	<input type="hidden" name="action" value="update" />
	</div>

	<p class="submit">	<input type="submit" name="zenlite_submit" class="button-primary" value="<?php _e('Update Theme', 'zenlite') ?>" /></p>
	
	<fieldset>
	<legend><strong><?php _e('Reset All Theme Options', 'zenlite');?></strong></legend>
	<p><label for="reset"><?php _e('Warning: Resetting the theme will remove all stored theme options from the database.', 'zenlite');?></label> 
	<input style="display:block;margin-top:1em;" type="submit" name="zenlite_reset" id="reset" class="button-secondary" value="<?php _e('Reset Theme', 'zenlite') ?>" /></p>

	</fieldset>
	
	</div></form>
</div>
	<?php
}

// Create admin menu item
if (!function_exists('theme_admin')) {
    // used by the admin panel hook
    function theme_admin() {    
        if (function_exists('add_menu_page')) {
			add_theme_page(__('Theme Options','zenlite_theme'), __('Theme Options','zen_theme'), 'edit_theme_options', basename('theme_style.php'),'zenlite_theme_admin');
    	}        
    }
}
add_action('admin_menu', 'theme_admin');

?>